@@ -32,8 +32,10 @@ TEST(TestLoadJointGroupPositionController, load_controller)
       ros2_control_test_assets::minimal_robot_urdf),
     executor, "test_controller_manager");
 
-  ASSERT_NO_THROW(cm.load_controller(
-    "test_joint_group_position_controller", "position_controllers/JointGroupPositionController"));
+  ASSERT_NE(
+    cm.load_controller(
+      "test_joint_group_position_controller", "position_controllers/JointGroupPositionController"),
+    nullptr);
 
   rclcpp::shutdown();
 }
